@@ -1,9 +1,9 @@
 import copy
 from logging import Formatter as _Formatter
 
-import colors
-import config
-from format_funcs import colored_format
+from betterLogger import colors
+from betterLogger import config
+from betterLogger.format_funcs import colored_format
 
 
 class Formatter(_Formatter):
@@ -18,11 +18,15 @@ class Formatter(_Formatter):
             new_name, new_msg = record.msg.split(": ", maxsplit=1)
 
             record.name = str(constants.logging.custom_name_per_log_array[record.name]) % new_name
-            record.msg = new_msg""" # fix this
+            record.msg = new_msg"""  # fix this
+
+        class_name = record.name
+        for log_name, shortened in config.log_names_to_shorten.items():
+            class_name = class_name.replace(log_name, shortened)
 
         record.msg = colored_format(config.log_format, self.use_color,
                                     custom_tags={"message": record.msg, "logger": self, "level": record.levelname,
-                                                 "class_name": record.name},
+                                                 "class_name": class_name},
                                     custom_colors={"LEVEL_COLOR": colors.level_to_code[record.levelname]})
         return _Formatter.format(self, record)
 
